pub fn decode_band_mask_ndarray(blob: &[u8]) -> Result<Option<ArrayD<u8>>>
Returns decoded band masks as an ndarray without decoding pixel values.
Returns an error for invalid blobs, inconsistent masks, or shape failure.