pub fn decode_band_set(blob: &[u8]) -> Result<DecodedBandSet>Expand description
Decodes every concatenated blob as a native-typed band set.
Errors
Returns an error if any band is invalid or band shapes disagree.
pub fn decode_band_set(blob: &[u8]) -> Result<DecodedBandSet>Decodes every concatenated blob as a native-typed band set.
Returns an error if any band is invalid or band shapes disagree.