pub fn decode_band_set_ndarray_f64(blob: &[u8]) -> Result<ArrayD<f64>>
Decodes and promotes a band set into an interleaved f64 ndarray.
f64
Returns an error for invalid data or shape construction failure.