decode_band_set_ndarray_f64_with_layout

Function decode_band_set_ndarray_f64_with_layout 

pub fn decode_band_set_ndarray_f64_with_layout(
    blob: &[u8],
    layout: BandLayout,
) -> Result<ArrayD<f64>>
Decodes and promotes a band set into an f64 ndarray using layout.

Errors

Returns an error for invalid data or shape construction failure.