decode_band_set_ndarray_with_mask

Function decode_band_set_ndarray_with_mask 

pub fn decode_band_set_ndarray_with_mask<T: BandElement>(
    blob: &[u8],
    mask: &[u8],
) -> Result<ArrayD<T>>
Decodes an externally masked band set into an interleaved ndarray.

Errors

Returns an error for invalid data, mask mismatch, type mismatch, or shape failure.