pub fn decode_first_to_f64(blob: &[u8]) -> Result<DecodedF64>Expand description
Decodes the first blob as promoted f64 samples and permits trailing bytes.
Errors
Returns an error when the first blob is malformed or unsupported.
pub fn decode_first_to_f64(blob: &[u8]) -> Result<DecodedF64>Decodes the first blob as promoted f64 samples and permits trailing bytes.
Returns an error when the first blob is malformed or unsupported.