decode_from_reader_with_mask

Function decode_from_reader_with_mask 

pub fn decode_from_reader_with_mask<R: Read + ?Sized>(
    reader: &mut R,
    mask: &[u8],
) -> Result<Decoded>
Reads and decodes one blob with an initial external mask.

Errors

Returns an error for I/O failure, truncation, invalid data, or a mismatched mask.