pub fn decode_ndarray_with_mask<T: NdArrayElement>(
blob: &[u8],
mask: &[u8],
) -> Result<ArrayD<T>>Expand description
Strictly decodes one externally masked blob into an ndarray.
Errors
Returns an error for invalid data, masks, types, or shape construction.