pub fn decode_band_set_vec<T: BandElement>(
blob: &[u8],
layout: BandLayout,
) -> Result<(BandSetInfo, Vec<T>)>Expand description
Decodes a band set into a homogeneous vector in the requested layout.
Errors
Returns an error for invalid input or an incompatible output element type.